@@ -85,7 +85,14 @@ class ScanWorker(threading.Thread):
             if not self.scan_report_instructions or not self.scan_report_instructions[-1].get(
                 "device_progress"
             ):
-                self.scan_report_instructions.append({"scan_progress": num_points})
+                self.scan_report_instructions.append(
+                    {
+                        "scan_progress": {
+                            "points": num_points,
+                            "show_table": active_rb.scan.show_live_table,
+                        }
+                    }
+                )
         self.current_instruction_queue_item.parent.queue_manager.send_queue_status()
 
         self._send_scan_status("open")
@@ -252,7 +259,7 @@ class ScanWorker(threading.Thread):
         The account name is retrieved from the current account message.
         If the account name is not found, an empty string will be used.
         """
-        current_account_msg = self.connector.get(MessageEndpoints.account())
+        current_account_msg = self.connector.get_last(MessageEndpoints.account(), "data")
         if current_account_msg:
             current_account = current_account_msg.value
             if not isinstance(current_account, str):
