@@ -15,14 +15,12 @@ from bec_lib.device import DeviceBase
 from bec_lib.devicemanager import DeviceManagerBase
 from bec_lib.endpoints import MessageEndpoints
 from bec_lib.logger import bec_logger
+from bec_server.scan_server.instruction_handler import InstructionHandler
 
 from .errors import LimitError, ScanAbortion
 from .path_optimization import PathOptimizerMixin
 from .scan_stubs import ScanStubs
 
-if TYPE_CHECKING:
-    from bec_server.scan_server.instruction_handler import InstructionHandler
-
 logger = bec_logger.logger
 
 
@@ -378,6 +376,7 @@ class ScanBase(RequestBase, PathOptimizerMixin):
         optim_trajectory: Literal["corridor", None] = None,
         monitored: list = None,
         return_to_start: bool = False,
+        show_live_table: bool = True,
         metadata: dict = None,
         **kwargs,
     ):
@@ -399,6 +398,7 @@ class ScanBase(RequestBase, PathOptimizerMixin):
         self.burst_at_each_point = burst_at_each_point
         self.frames_per_trigger = frames_per_trigger
         self.optim_trajectory = optim_trajectory
+        self.show_live_table = show_live_table
         self.burst_index = 0
         self._baseline_status = None
         self.scan_number = None
@@ -931,7 +931,7 @@ class FermatSpiralScan(ScanBase):
     gui_config = {
         "Device 1": ["motor1", "start_motor1", "stop_motor1"],
         "Device 2": ["motor2", "start_motor2", "stop_motor2"],
-        "Movement Parameters": ["step", "spiral_type", "relative"],
+        "Movement Parameters": ["step", "spiral_type", "relative", "optim_trajectory"],
         "Acquisition Parameters": ["exp_time", "settling_time", "burst_at_each_point"],
     }
 
