@@ -191,6 +191,7 @@ def test_open_scan(scan_worker_mock, instr, corr_num_points, scan_id):
                     ) as queue_status_mock:
                         active_rb = queue_mock.active_request_block
                         active_rb.scan_report_instructions = []
+                        active_rb.scan.show_live_table = True
                         worker.open_scan(instr)
 
                         if not scan_id:
@@ -204,7 +205,7 @@ def test_open_scan(scan_worker_mock, instr, corr_num_points, scan_id):
                             assert worker.scan_motors == ["bpm4i"]
                         init_mock.assert_called_once_with(active_rb, instr, corr_num_points)
                         assert active_rb.scan_report_instructions == [
-                            {"scan_progress": corr_num_points}
+                            {"scan_progress": {"points": corr_num_points, "show_table": True}}
                         ]
                         queue_status_mock.assert_called_once()
                         send_mock.assert_called_once_with("open")
@@ -697,7 +698,7 @@ def test_worker_update_instr_with_scan_report_no_update_with_report(msg, scan_wo
     arb = worker.current_instruction_queue_item.active_request_block = mock.MagicMock(
         spec=RequestBlock
     )
-    arb.scan_report_instructions = [{"scan_progress": 10}]
+    arb.scan_report_instructions = [{"scan_progress": {"points": 10, "show_table": True}}]
     with mock.patch.object(worker, "forward_instruction") as forward_mock:
         worker._instruction_step(msg)
         worker.update_instr_with_scan_report(msg)
@@ -760,14 +761,16 @@ def test_worker_get_file_base_path(
     file_writer_base_path_orig = worker.parent._service_config.config["file_writer"]["base_path"]
     try:
         worker.parent._service_config.config["file_writer"]["base_path"] = base_path
-        with mock.patch.object(worker.connector, "get", return_value=current_account_msg):
+        with mock.patch.object(worker.connector, "get_last", return_value=current_account_msg):
             if raises_error:
                 with pytest.raises(ValueError) as exc_info:
                     worker._get_file_base_path()
             else:
                 file_path = worker._get_file_base_path()
                 assert file_path == expected_path
-                worker.connector.get.assert_called_once_with(MessageEndpoints.account())
+                worker.connector.get_last.assert_called_once_with(
+                    MessageEndpoints.account(), "data"
+                )
     finally:
         worker.parent._service_config.config["file_writer"][
             "base_path"
